@@ -394,6 +394,7 @@ void drawdot(int xpos, int ypos)
       (*newarc)->width = 1.0;
       (*newarc)->style = FILLED | FILLSOLID | NOBORDER;
       (*newarc)->passed = NULL;
+      (*newarc)->cycle = -1;
       calcarc(*newarc);
       register_for_undo(XCF_Arc, UNDO_DONE, areawin->topinstance, *newarc);
    }
@@ -411,6 +412,7 @@ void labeldefaults(labelptr newlabel, u_char dopin, int x, int y)
    newlabel->scale = areawin->textscale;
    newlabel->string = (stringpart *)malloc(sizeof(stringpart));
    newlabel->passed = NULL;
+   newlabel->cycle = -1;
 
    /* initialize string with font designator */
    newlabel->string->type = FONT_NAME;
@@ -1044,6 +1046,7 @@ void splinedefaults(splineptr newspline, int x, int y)
    newspline->style = areawin->style;
    newspline->color = areawin->color;
    newspline->passed = NULL;
+   newspline->cycle = -1;
    calcspline(newspline);
 }
 
@@ -1060,8 +1063,8 @@ void splinebutton(int x, int y)
    areawin->editpart = topobject->parts;
 
    snap(x, y, &userpt);
-   areawin->editcycle = 3;
    splinedefaults(*newspline, userpt.x, userpt.y);
+   (*newspline)->cycle = 3;
 
    XcSetXORFg(areawin->color, BACKGROUND);
    XcSetFunction(GXxor);
@@ -1073,31 +1076,110 @@ void splinebutton(int x, int y)
    eventmode = SPLINE_MODE;
 }
 
+/*----------------------------------------------------------------------*/
+/* Find the element of a path that is currently being edited.	This	*/
+/* will be the element whose cycle is not the default -1 value.		*/
+/*----------------------------------------------------------------------*/
+
+genericptr getsubpart(pathptr editpath)
+{
+   genericptr *pgen;
+   for (pgen = editpath->plist; pgen < editpath->plist + editpath->parts; pgen++) {
+      switch (ELEMENTTYPE(*pgen)) {
+	 case POLYGON:
+	    if ((TOPOLY(pgen))->cycle >= 0) return *pgen;
+	    break;
+	 case ARC:
+	    if ((TOARC(pgen))->cycle >= 0) return *pgen;
+	    break;
+	 case SPLINE:
+	    if ((TOSPLINE(pgen))->cycle >= 0) return *pgen;
+	    break;
+      }
+   }
+   return NULL;
+}
+
+/*----------------------------------------------------------------------*/
+/* Adjust path points for parts connected to points that have been	*/
+/* adjusted during an edit.						*/
+/*----------------------------------------------------------------------*/
+
+void updatepath(pathptr thepath, XPoint *origpt, XPoint *newpt)
+{
+   genericptr *ggen;
+   polyptr thispoly;
+   splineptr thisspline;
+   XPoint *ppt;
+
+   for (ggen = thepath->plist; ggen < thepath->plist + thepath->parts; ggen++) {
+      switch (ELEMENTTYPE(*ggen)) {
+	 case POLYGON:
+	    thispoly = TOPOLY(ggen);
+	    for (ppt = thispoly->points; ppt < thispoly->points + thispoly->number;
+			ppt++) {
+	       if ((ppt->x == origpt->x) && (ppt->y == origpt->y)) {
+	          UDrawPolygon(thispoly);
+		  *ppt = *newpt;
+	          UDrawPolygon(thispoly);
+	          break; 
+	       }
+	    }
+	    break;
+
+	 case SPLINE:
+	    thisspline = TOSPLINE(ggen);
+	    if ((thisspline->ctrl[0].x == origpt->x) &&
+			(thisspline->ctrl[0].y == origpt->y)) {
+	       UDrawSpline(thisspline);
+	       thisspline->ctrl[1].x += (newpt->x - origpt->x);
+	       thisspline->ctrl[1].y += (newpt->y - origpt->y);
+	       thisspline->ctrl[0] = *newpt;
+	       calcspline(thisspline);
+	       UDrawSpline(thisspline);
+	    }
+	    else if ((thisspline->ctrl[3].x == origpt->x) &&
+			(thisspline->ctrl[3].y == origpt->y)) {
+	       UDrawSpline(thisspline);
+	       thisspline->ctrl[2].x += (newpt->x - origpt->x);
+	       thisspline->ctrl[2].y += (newpt->y - origpt->y);
+	       thisspline->ctrl[3] = *newpt;
+	       calcspline(thisspline);
+	       UDrawSpline(thisspline);
+	    }
+	    break;
+      }
+   }
+}
+
 /*------------------------------------*/
 /* Track a spline during mouse motion */
 /*------------------------------------*/
 
 void trackspline(xcWidget w, caddr_t clientdata, caddr_t calldata)
 {
-   XPoint       newpos;
+   XPoint       origpt, newpos;
    splineptr    newspline;
 
-   newspline = (eventmode == EPATH_MODE) ?
-               (splineptr)(*((*((pathptr *)EDITPART))->plist
-		+ areawin->editsubpart)) : TOSPLINE(EDITPART);
+   if (eventmode == EPATH_MODE) {
+      newspline = (splineptr)getsubpart(TOPATH(EDITPART));
+   }
+   else {
+      newspline = TOSPLINE(EDITPART);
+   }
    newpos = UGetCursorPos();
    u2u_snap(&newpos);
    if (areawin->save.x == newpos.x && areawin->save.y == newpos.y) return;
 
    UDrawEditSpline(newspline);
 
-   if (areawin->editcycle == 0 || areawin->editcycle == 3) {
-      short cpoint = (areawin->editcycle == 0) ? 1 : 2;
-      newspline->ctrl[cpoint].x += (newpos.x - newspline->ctrl[areawin->editcycle].x);
-      newspline->ctrl[cpoint].y += (newpos.y - newspline->ctrl[areawin->editcycle].y);
+   if (newspline->cycle == 0 || newspline->cycle == 3) {
+      short cpoint = (newspline->cycle == 0) ? 1 : 2;
+      newspline->ctrl[cpoint].x += (newpos.x - newspline->ctrl[newspline->cycle].x);
+      newspline->ctrl[cpoint].y += (newpos.y - newspline->ctrl[newspline->cycle].y);
    }
-   newspline->ctrl[areawin->editcycle].x = newpos.x;
-   newspline->ctrl[areawin->editcycle].y = newpos.y;
+   origpt = newspline->ctrl[newspline->cycle];
+   newspline->ctrl[newspline->cycle] = newpos;
 
    calcspline(newspline);
    UDrawEditSpline(newspline);
@@ -1106,9 +1188,31 @@ void trackspline(xcWidget w, caddr_t clientdata, caddr_t calldata)
    areawin->save.x = newpos.x;
    areawin->save.y = newpos.y;
 
+   if (eventmode == EPATH_MODE)
+      if (newspline->cycle == 0 || newspline->cycle == 3)
+         updatepath(TOPATH(EDITPART), &origpt, &newpos);
+
    flusharea();
 }
 
+/*--------------------------------------*/
+/* Track a path during mouse motion	*/
+/*--------------------------------------*/
+
+void trackpath(xcWidget w, caddr_t clientdata, caddr_t calldata)
+{
+   genericptr ggen = getsubpart(TOPATH(EDITPART));
+
+   switch (ELEMENTTYPE(ggen)) {
+      case POLYGON:
+	 trackpoly(w, clientdata, calldata);
+	 break;
+      case SPLINE:
+	 trackspline(w, clientdata, calldata);
+	 break;
+   }
+}
+
 /*--------------------------------------*/
 /* Set default values for an arc	*/
 /*--------------------------------------*/
@@ -1125,6 +1229,7 @@ void arcdefaults(arcptr newarc, int x, int y)
    newarc->angle1 = 0;
    newarc->angle2 = 360;
    newarc->passed = NULL;
+   newarc->cycle = -1;
    calcarc(newarc);
 }
 
@@ -1140,9 +1245,9 @@ void arcbutton(int x, int y)
    NEW_ARC(newarc, topobject);
    areawin->editpart = topobject->parts;
    snap(x, y, &userpt);
-   areawin->editcycle = 0;
    saveratio = 1.0;
    arcdefaults(*newarc, userpt.x, userpt.y);
+   (*newarc)->cycle = 0;
 
    XcSetXORFg(areawin->color, BACKGROUND);
    XcSetFunction(GXxor);
@@ -1165,9 +1270,7 @@ void trackarc(xcWidget w, caddr_t clientdata, caddr_t calldata)
    arcptr newarc;
    double adjrat;
 
-   newarc = (eventmode == EPATH_MODE) ?
-	    (arcptr)(*((*((pathptr *)EDITPART))->plist
-	    + areawin->editsubpart)) : TOARC(EDITPART);
+   newarc = TOARC(EDITPART);
 
    newpos = UGetCursorPos();
    u2u_snap(&newpos);
@@ -1176,15 +1279,15 @@ void trackarc(xcWidget w, caddr_t clientdata, caddr_t calldata)
    UDrawArc(newarc);
    UDrawXLine(areawin->save, newarc->position);
 
-   if (areawin->editcycle == 1 || areawin->editcycle == 2) {
+   if (newarc->cycle == 1 || newarc->cycle == 2) {
       float *angleptr, tmpang;
 
       adjrat = (newarc->yaxis == 0) ? 1 :
 		(double)(abs(newarc->radius)) / (double)newarc->yaxis;
-      angleptr = (areawin->editcycle == 1) ? &newarc->angle1 : &newarc->angle2;
+      angleptr = (newarc->cycle == 1) ? &newarc->angle1 : &newarc->angle2;
       tmpang = (float)(atan2((double)(newpos.y - newarc->position.y) * adjrat,
 	   (double)(newpos.x - newarc->position.x)) / RADFAC);
-      if (areawin->editcycle == 1) {
+      if (newarc->cycle == 1) {
 	 if (tmpang > newarc->angle2) tmpang -= 360;
 	 else if (newarc->angle2 - tmpang > 360) newarc->angle2 -= 360;
       }
@@ -1201,7 +1304,7 @@ void trackarc(xcWidget w, caddr_t clientdata, caddr_t calldata)
       if (newarc->angle2 <= newarc->angle1)
 	 newarc->angle1 -= 360;
    }
-   else if (areawin->editcycle == 0) {
+   else if (newarc->cycle == 0) {
       short direc = (newarc->radius < 0);
       newarc->radius = wirelength(&newpos, &(newarc->position));
       newarc->yaxis = (short)((double)newarc->radius * saveratio);
@@ -1237,6 +1340,7 @@ void polydefaults(polyptr newpoly, int number, int x, int y)
    newpoly->width = areawin->linewidth;
    newpoly->number = number;
    newpoly->passed = NULL;
+   newpoly->cycle = -1;
    if (number == 0)
       newpoly->points = NULL;
    else {
@@ -1280,7 +1384,7 @@ void boxbutton(int x, int y)
 
 void trackbox(xcWidget w, caddr_t clientdata, caddr_t calldata)
 {
-   XPoint newpos;
+   XPoint 	newpos, upos;
    polyptr      newbox;
    pointlist	pointptr;
 
@@ -1305,23 +1409,38 @@ void trackbox(xcWidget w, caddr_t clientdata, caddr_t calldata)
    flusharea();
 }
 
-/*----------------------------------*/
-/* Track a wire during mouse motion */
-/*----------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Track a wire during mouse motion					*/
+/* Note:  The manhattanize algorithm will change the effective cursor	*/
+/* position to keep the wire manhattan if the wire is only 1 segment.	*/
+/* It will change the previous point's position if the wire has more	*/
+/* than one segment.  They are called at different times to ensure the	*/
+/* wire redraw is correct.						*/
+/*----------------------------------------------------------------------*/
 
 void trackwire(xcWidget w, caddr_t clientdata, caddr_t calldata)
 {
-   XPoint newpos, *tpoint;
+   XPoint newpos, upos, *tpoint;
    polyptr	newwire;
 
    newwire = TOPOLY(EDITPART);
-   newpos = UGetCursorPos();
-   u2u_snap(&newpos);
-   if (areawin->manhatn) manhattanize(&newpos, newwire);
+
+   if (areawin->attachto >= 0) {
+      upos = UGetCursorPos();
+      findattach(&newpos, NULL, &upos); 
+   }
+   else {
+      newpos = UGetCursorPos();
+      u2u_snap(&newpos);
+      if (areawin->manhatn && (newwire->number == 2))
+	 manhattanize(&newpos, newwire, -1, TRUE);
+   }
 
    if (areawin->save.x != newpos.x || areawin->save.y != newpos.y) {
       tpoint = newwire->points + newwire->number - 1;
       UDrawPolygon(newwire);
+      if (areawin->manhatn && (newwire->number > 2))
+	 manhattanize(&newpos, newwire, -1, TRUE);
       tpoint->x = newpos.x;
       tpoint->y = newpos.y;
       UDrawPolygon(newwire);
@@ -1337,7 +1456,7 @@ void trackwire(xcWidget w, caddr_t clientdata, caddr_t calldata)
 /* Start drawing a polygon. */
 /*--------------------------*/
 
-void startwire(XPoint userpt)
+void startwire(XPoint *userpt)
 {
    polyptr *newwire;
    pointlist pointptr;
@@ -1353,9 +1472,10 @@ void startwire(XPoint userpt)
    (*newwire)->width = areawin->linewidth;
    (*newwire)->points = (pointlist) malloc(2 * sizeof(XPoint));
    (*newwire)->passed = NULL;
+   (*newwire)->cycle = -1;
    pointptr = (*newwire)->points;
-   pointptr->x = (pointptr + 1)->x = areawin->save.x = userpt.x;
-   pointptr->y = (pointptr + 1)->y = areawin->save.y = userpt.y;
+   pointptr->x = (pointptr + 1)->x = areawin->save.x = userpt->x;
+   pointptr->y = (pointptr + 1)->y = areawin->save.y = userpt->y;
 
    XcSetXORFg(areawin->color, BACKGROUND);
    XcSetFunction(GXxor);
@@ -1368,7 +1488,7 @@ void startwire(XPoint userpt)
 /*----------------------------------------------------------*/
 /* Find which points should track along with the edit point */
 /* in polygon RHOMBOID or MANHATTAN edit modes.		    */
-/* (point number is stored in areawin->editcycle)	    */
+/* (point number is stored in lastpoly->cycle)	    	    */
 /*----------------------------------------------------------*/
 
 void finddir(polyptr lastpoly)
@@ -1378,13 +1498,13 @@ void finddir(polyptr lastpoly)
    savedir = NONE;
    if (areawin->boxedit == NORMAL) return;
 
-   savept = lastpoly->points + areawin->editcycle;
+   savept = lastpoly->points + lastpoly->cycle;
 
    /* find points before and after the edit point */      
 
-   lpt = (areawin->editcycle == 0) ? ((lastpoly->style & UNCLOSED) ?
+   lpt = (lastpoly->cycle == 0) ? ((lastpoly->style & UNCLOSED) ?
 	 NULL : lastpoly->points + lastpoly->number - 1) : savept - 1;
-   npt = (areawin->editcycle == lastpoly->number - 1) ?
+   npt = (lastpoly->cycle == lastpoly->number - 1) ?
 	 ((lastpoly->style & UNCLOSED) ? NULL : lastpoly->points) :
 	 savept + 1;
 
@@ -1449,63 +1569,80 @@ void finddir(polyptr lastpoly)
 
 void trackpoly(xcWidget w, caddr_t clientdata, caddr_t calldata)
 {
-   XPoint newpos, *curpt;
+   XPoint newpos, origpt, *curpt;
    polyptr      newpoly;
-   int		nullint;
 
-   newpoly = (eventmode == EPATH_MODE) ?
-	     (polyptr)(*((*((pathptr *)EDITPART))->plist
-	     + areawin->editsubpart)) : TOPOLY(EDITPART);
+   if (eventmode == EPATH_MODE) 
+      newpoly = (polyptr)getsubpart(TOPATH(EDITPART));
+   else
+      newpoly = TOPOLY(EDITPART);
+
    newpos = UGetCursorPos();
    u2u_snap(&newpos);
+
+   /* force attachment if required */
+   if (areawin->attachto >= 0) {
+      XPoint apos;
+      findattach(&apos, NULL, &newpos); 
+      newpos = apos;
+   }
+
    if (areawin->save.x == newpos.x && areawin->save.y == newpos.y) return;
 
    UDrawPolygon(newpoly);
 
    /* find the point under consideration */
-   curpt = newpoly->points + areawin->editcycle;
+   curpt = newpoly->points + newpoly->cycle;
 
-   if (areawin->attachto) {
-      findattach(curpt, &nullint, &newpos); 
-   }
-   else {
+   /* find points to either side of the edit point */
 
-      /* find points to either side of the edit point */
+   if (areawin->boxedit != NORMAL) {
+      XPoint *fpt = NULL, *bpt = NULL;
+      int deltax = newpos.x - curpt->x;
+      int deltay = newpos.y - curpt->y; 
 
-      if (areawin->boxedit != NORMAL) {
-         XPoint *fpt = NULL, *bpt = NULL;
-	 int deltax = newpos.x - curpt->x;
-	 int deltay = newpos.y - curpt->y; 
+      if (curpt > newpoly->points) bpt = curpt - 1;
+      else if (!(newpoly->style & UNCLOSED))
+	 bpt = newpoly->points + newpoly->number - 1;
+      if (curpt < newpoly->points + newpoly->number - 1) fpt = curpt + 1;
+      else if (!(newpoly->style & UNCLOSED)) fpt = newpoly->points;
 
-         if (curpt > newpoly->points) bpt = curpt - 1;
-         else if (!(newpoly->style & UNCLOSED))
-	    bpt = newpoly->points + newpoly->number - 1;
-         if (curpt < newpoly->points + newpoly->number - 1) fpt = curpt + 1;
-         else if (!(newpoly->style & UNCLOSED)) fpt = newpoly->points;
+      /* enforce constraints */
 
-	 /* enforce constraints */
+      if (bpt != NULL) {
+	 origpt = *bpt;
+	 if (savedir & LASTX) bpt->x += deltax;
+	 if (savedir & LASTY) bpt->y += deltay;
 
-	 if (bpt != NULL) {
-	    if (savedir & LASTX) bpt->x += deltax;
-	    if (savedir & LASTY) bpt->y += deltay;
-	 }
-	 if (fpt != NULL) {
-	    if (savedir & NEXTX) fpt->x += deltax;
-	    if (savedir & NEXTY) fpt->y += deltay;
-	 }
+	 if ((eventmode == EPATH_MODE) && (savedir & (LASTX | LASTY)))
+	    if (newpoly->cycle == 1)
+	       updatepath(TOPATH(EDITPART), &origpt, bpt);
       }
+      if (fpt != NULL) {
+	 origpt = *fpt;
+	 if (savedir & NEXTX) fpt->x += deltax;
+	 if (savedir & NEXTY) fpt->y += deltay;
 
-      /* update position of the point under consideration */
-
-      curpt->x = newpos.x;
-      curpt->y = newpos.y;
+	 if ((eventmode == EPATH_MODE) && (savedir & (NEXTX | NEXTY)))
+	    if (newpoly->cycle == newpoly->number - 2)
+	       updatepath(TOPATH(EDITPART), &origpt, fpt);
+      }
    }
 
+   /* update position of the point under consideration */
+
+   origpt = *curpt;
+   *curpt = newpos;
+
    UDrawPolygon(newpoly);
    printpos(newpos.x, newpos.y);
    areawin->save.x = newpos.x;
    areawin->save.y = newpos.y;
 
+   if (eventmode == EPATH_MODE)
+      if (newpoly->cycle == 0 || newpoly->cycle == newpoly->number - 1)
+         updatepath(TOPATH(EDITPART), &origpt, &newpos);
+
    flusharea();
 }
 
@@ -1704,6 +1841,7 @@ void join()
    XPoint    *testpoint, *testpoint2, *begpoint, *endpoint, arcpoint[4];
    XPoint    *begpoint2, *endpoint2;
    Boolean   allpolys = True;
+   objectptr delobj;
 
    numpolys = numlabels = 0;
    for (selectobj = areawin->selectlist; selectobj < areawin->selectlist
@@ -1850,6 +1988,7 @@ void join()
 
    if (allpolys) {
       NEW_POLY(newpoly, topobject);
+      topobject->parts++;
 
       (*newpoly)->number = numpoints;
       (*newpoly)->points = (pointlist) malloc(numpoints * sizeof(XPoint));
@@ -1857,6 +1996,7 @@ void join()
       (*newpoly)->style  = polytype;
       (*newpoly)->color  = polycolor;
       (*newpoly)->passed = NULL;
+      (*newpoly)->cycle = -1;
 
       /* insert the points into the new polygon */
 
@@ -1886,32 +2026,47 @@ void join()
 
       /* delete the old elements from the list */
 
-      for (sptr = scount; sptr < scount + numpolys; sptr++) {
-	 easydraw(*sptr, DOFORALL);
-	 freepathparts(sptr, 1);
-	 /* revise the list of path elements */
-	 for (sptr2 = sptr + 1; sptr2 < scount + numpolys; sptr2++)
-	    if (*sptr2 > *sptr) (*sptr2)--;
-      }
+      register_for_undo(XCF_Wire, UNDO_MORE, areawin->topinstance, *newpoly);
+
+      delobj = delete_element(areawin->topinstance, areawin->selectlist,
+		areawin->selects, NORMAL);
+      register_for_undo(XCF_Delete, UNDO_DONE, areawin->topinstance,
+                delobj, NORMAL);
+
+  //  standard_element_delete(NORMAL);
+
+  //   for (sptr = scount; sptr < scount + numpolys; sptr++) {
+  //	 easydraw(*sptr, DOFORALL);
+  //	 freepathparts(sptr, 1);
+  //	 /* revise the list of path elements */
+  //	 for (sptr2 = sptr + 1; sptr2 < scount + numpolys; sptr2++)
+  //	    if (*sptr2 > *sptr) (*sptr2)--;
+  //   }
+
       XcSetForeground((*newpoly)->color);
       UDrawPolygon(*newpoly);
+
    }
    else {	/* create a path */
-      short newcount = 0;
 
       NEW_PATH(newpath, topobject);
       (*newpath)->style = polytype;
       (*newpath)->color = polycolor;
       (*newpath)->width = polywidth;
-      (*newpath)->parts = numpolys;
-      (*newpath)->plist = (genericptr *) malloc(numpolys * sizeof(genericptr));
+      (*newpath)->parts = 0;
+      (*newpath)->plist = (genericptr *) malloc(sizeof(genericptr));
       (*newpath)->passed = NULL;
 
       /* move the elements from the top level into the path structure */
 
-      for (sptr = order; sptr < order + numpolys; sptr++, newcount++) {
+      for (sptr = order; sptr < order + numpolys; sptr++) {
 	 genericptr *oldelem = topobject->plist + *sptr;
-	 genericptr *newelem = (*newpath)->plist + newcount;
+	 genericptr *newelem;
+
+	 (*newpath)->parts++;
+         (*newpath)->plist = (genericptr *) realloc((*newpath)->plist,
+			(*newpath)->parts * sizeof(genericptr));
+	 newelem = (*newpath)->plist + (*newpath)->parts - 1;
 	 *newelem = *oldelem;
 
 	 /* reverse point order if necessary */
@@ -1922,7 +2077,6 @@ void join()
 		  reversepoints(TOPOLY(newelem)->points, TOPOLY(newelem)->number);
 	          break;
 	       case ARC:
-		  reversefpoints(TOARC(newelem)->points, TOARC(newelem)->number);
 		  TOARC(newelem)->radius = -TOARC(newelem)->radius;
 	          break;
 	       case SPLINE:
@@ -1931,7 +2085,12 @@ void join()
 	          break;
 	    }
 	 }
+
+	 /* decompose arcs into bezier curves */
+	 if (ELEMENTTYPE(*newelem) == ARC)
+	    decomposearc(*newpath);
       }
+
       for (sptr = scount; sptr < scount + numpolys; sptr++) {
 	 easydraw(*sptr, DOFORALL);
 	 removep(sptr, 1);  /* close up list but do not delete elements */
@@ -1942,11 +2101,11 @@ void join()
       
       XcSetForeground((*newpath)->color);
       UDrawPath(*newpath);
+      topobject->parts++;
    }
 
    /* clean up */
 
-   topobject->parts++;
    incr_changes(topobject);
    clearselects();
    free(scount);
@@ -1981,12 +2140,20 @@ void wire_op(int op, int x, int y)
    snap(x, y, &userpt);
 
    newwire = TOPOLY(EDITPART);
-   if (areawin->manhatn) manhattanize(&userpt, newwire);
- 
-   /* This undraws the wire */
 
+   /* This undraws the wire */
    UDrawPolygon(newwire);
 
+   if (areawin->attachto >= 0) {
+      XPoint apos;
+      findattach(&apos, NULL, &userpt);
+      userpt = apos;
+      areawin->attachto = -1;
+   }
+   else {
+      if (areawin->manhatn) manhattanize(&userpt, newwire, -1, TRUE);
+   }
+ 
    tpoint = newwire->points + newwire->number - 1;
    tpoint->x = userpt.x;
    tpoint->y = userpt.y;
