@@ -106,9 +106,118 @@ long finddist(XPoint *linept1, XPoint *linept2, XPoint *userpt)
    }
 }
 
-/*------------------------------------------------------------------------*/
-/* Calculate points for an arc						  */
-/*------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Decompose an arc segment into one to four bezier curves according	*/
+/* the approximation algorithm lifted from the paper by  L. Maisonobe	*/
+/* (spaceroots.org).  This decomposition is done when an arc in a path	*/
+/* is read from an (older) xcircuit file, or when an arc is a selected	*/
+/* item when a path is created.	 Because arcs are decomposed when	*/
+/* encountered, we assume that the arc is the last element of the path.	*/
+/*----------------------------------------------------------------------*/
+
+void decomposearc(pathptr thepath)
+{
+   float fnc, ang1, ang2;
+   short ncurves, i;
+   arcptr thearc;
+   genericptr *pgen;
+   splineptr *newspline;
+   double nu1, nu2, lambda1, lambda2, alpha, tansq;
+   XfPoint E1, E2, Ep1, Ep2;
+   Boolean reverse = FALSE;
+
+   pgen = thepath->plist + thepath->parts - 1;
+   if (ELEMENTTYPE(*pgen) != ARC) return;
+   thearc = TOARC(pgen);
+
+   if (thearc->radius < 0) {
+      reverse = TRUE;
+      thearc->radius = -thearc->radius;
+   }
+
+   fnc = (thearc->angle2 - thearc->angle1) / 90.0;
+   ncurves = (short)fnc;
+   if (fnc - (float)((int)fnc) > 0.01) ncurves++;
+
+   thepath->parts--;  /* Forget the arc */
+
+   for (i = 0; i < ncurves; i++) {
+      if (reverse) {			/* arc path is reverse direction */
+         if (i == 0)
+	    ang1 = thearc->angle2;
+         else
+	    ang1 -= 90;
+
+         if (i == ncurves - 1)
+	    ang2 = thearc->angle1;
+         else
+	    ang2 = ang1 - 90;
+      }
+      else {				/* arc path is forward direction */
+         if (i == 0)
+	    ang1 = thearc->angle1;
+         else
+	    ang1 += 90;
+
+         if (i == ncurves - 1)
+	    ang2 = thearc->angle2;
+         else
+	    ang2 = ang1 + 90;
+      }
+
+      lambda1 = (double)ang1 * RADFAC;
+      lambda2 = (double)ang2 * RADFAC;
+
+      nu1 = atan2(sin(lambda1) / (double)thearc->yaxis,
+		cos(lambda1) / (double)thearc->radius);
+      nu2 = atan2(sin(lambda2) / (double)thearc->yaxis,
+		cos(lambda2) / (double)thearc->radius);
+      E1.x = (float)thearc->position.x + 
+		(float)thearc->radius * (float)cos(nu1);
+      E1.y = (float)thearc->position.y +
+		(float)thearc->yaxis * (float)sin(nu1);
+      E2.x = (float)thearc->position.x + 
+		(float)thearc->radius * (float)cos(nu2);
+      E2.y = (float)thearc->position.y +
+		(float)thearc->yaxis * (float)sin(nu2);
+      Ep1.x = -(float)thearc->radius * (float)sin(nu1);
+      Ep1.y = (float)thearc->yaxis * (float)cos(nu1);
+      Ep2.x = -(float)thearc->radius * (float)sin(nu2);
+      Ep2.y = (float)thearc->yaxis * (float)cos(nu2);
+
+      tansq = tan((nu2 - nu1) / 2.0);
+      tansq *= tansq;
+      alpha = sin(nu2 - nu1) * 0.33333 * (sqrt(4 + (3 * tansq)) - 1);
+
+      NEW_SPLINE(newspline, thepath);
+      splinedefaults(*newspline, 0, 0);
+      (*newspline)->style = thearc->style;
+      (*newspline)->color = thearc->color;
+      (*newspline)->width = thearc->width;
+
+      (*newspline)->ctrl[0].x = E1.x;
+      (*newspline)->ctrl[0].y = E1.y;
+
+      (*newspline)->ctrl[1].x = E1.x + alpha * Ep1.x;
+      (*newspline)->ctrl[1].y = E1.y + alpha * Ep1.y;
+
+      (*newspline)->ctrl[2].x = E2.x - alpha * Ep2.x;
+      (*newspline)->ctrl[2].y = E2.y - alpha * Ep2.y;
+
+      (*newspline)->ctrl[3].x = E2.x;
+      (*newspline)->ctrl[3].y = E2.y;
+
+      calcspline(*newspline);
+      thepath->parts++;
+   }
+
+   /* Delete the arc */
+   free_single((genericptr)thearc);
+}
+
+/*----------------------------------------------------------------------*/
+/* Calculate points for an arc						*/
+/*----------------------------------------------------------------------*/
 
 void calcarc(arcptr thearc)
 {
@@ -817,19 +926,96 @@ void InvTransformPoints(XPoint *points, XPoint *newpoints, short number,
    UTransformbyCTM(&LCTM, points, newpoints, number);
 }
 
-/*------------------------------------------------------------------------*/
-/* Translate wire coords to force wire to horizontal or vertical position */
-/*------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Adjust wire coords to force a wire to a horizontal or vertical	*/
+/* position.								*/
+/* "pospt" is the target position for the point of interest.		*/
+/* "cycle" is the point number in the polygon of the point of interest.	*/
+/* cycle == -1 is equivalent to the last point of the polygon.		*/
+/* If "strict" is TRUE then single-segment wires are forced manhattan	*/
+/* even if that means that the endpoint drifts from the target point.	*/
+/* If "strict" is FALSE then single-segment wires will become non-	*/
+/* manhattan so that the target point is reached.			*/
+/* NOTE:  It might be preferable to add a segment to maintain a		*/
+/* manhattan layout, except that we want to avoid merging nets		*/
+/* together. . .							*/
+/*----------------------------------------------------------------------*/
 
-void manhattanize(XPoint *pospt, polyptr newwire)
+void manhattanize(XPoint *pospt, polyptr newpoly, short cycle, Boolean strict)
 {
-   short deltax, deltay;
-   XPoint *tpoint = newwire->points + newwire->number - 2;
+   XPoint *curpt, *bpt, *bbpt, *fpt, *ffpt;
+   int deltax, deltay;
 
-   deltax = abs(tpoint->x - pospt->x);
-   deltay = abs(tpoint->y - pospt->y);
-   if (deltay > deltax) pospt->x = tpoint->x;
-   else pospt->y = tpoint->y;
+   if (newpoly->number == 1) return;	/* sanity check */
+
+   if (cycle == -1 || cycle == newpoly->number - 1) {
+      curpt = newpoly->points + newpoly->number - 1;
+      bpt = newpoly->points + newpoly->number - 2;
+      fpt = NULL;
+      ffpt = NULL;
+      if (newpoly->number > 2)
+	 bbpt = newpoly->points + newpoly->number - 3;
+      else
+	 bbpt = NULL;
+   } 
+   else if (cycle == 0) {
+      curpt = newpoly->points;
+      fpt = newpoly->points + 1;
+      bpt = NULL;
+      bbpt = NULL;
+      if (newpoly->number > 2)
+	 ffpt = newpoly->points + 2;
+      else
+	 ffpt = NULL;
+   }
+   else {
+      curpt = newpoly->points + cycle;
+      fpt = newpoly->points + cycle + 1;
+      bpt = newpoly->points + cycle - 1;
+      if (cycle > 1)
+	 bbpt = newpoly->points + cycle - 2;
+      else
+	 bbpt = NULL;
+
+      if (cycle < newpoly->number - 2)
+	 ffpt = newpoly->points + cycle + 2;
+      else
+	 ffpt = NULL;
+   }
+
+   /* enforce constraints on point behind cycle position */
+
+   if (bpt != NULL) {
+      if (bbpt != NULL) {
+         if (bpt->x == bbpt->x) bpt->y = pospt->y;
+         if (bpt->y == bbpt->y) bpt->x = pospt->x;
+      }
+      else if (strict) {
+         deltax = abs(bpt->x - pospt->x);
+         deltay = abs(bpt->y - pospt->y);
+
+         /* Only one segment---just make sure it's horizontal or vertical */
+         if (deltay > deltax) pospt->x = bpt->x;
+         else pospt->y = bpt->y;
+      }
+   }
+
+   /* enforce constraints on point forward of cycle position */
+
+   if (fpt != NULL) {
+      if (ffpt != NULL) {
+         if (fpt->x == ffpt->x) fpt->y = pospt->y;
+         if (fpt->y == ffpt->y) fpt->x = pospt->x;
+      }
+      else if (strict) {
+         deltax = abs(fpt->x - pospt->x);
+         deltay = abs(fpt->y - pospt->y);
+
+         /* Only one segment---just make sure it's horizontal or vertical */
+         if (deltay > deltax) pospt->x = fpt->x;
+         else pospt->y = fpt->y;
+      }
+   }
 }
 
 /*----------------------------------------------------------------------*/
@@ -1924,7 +2110,6 @@ void UDrawPath(pathptr thepath)
    genericptr	*genpath;
    polyptr	thepoly;
    splineptr	thespline;
-   arcptr	thearc;
    int		pathsegs = 0, curseg = 0;
    
    for (genpath = thepath->plist; genpath < thepath->plist + thepath->parts;
@@ -1944,13 +2129,6 @@ void UDrawPath(pathptr thepath)
    	    makesplinepath(thespline, tmppoints + curseg);
 	    curseg = pathsegs;
 	    break;
-	 case ARC:
-	    thearc = TOARC(genpath);
-	    pathsegs += thearc->number;
-	    tmppoints = (pointlist) realloc(tmppoints, pathsegs * sizeof(XPoint));
-   	    UfTransformbyCTM(DCTM, thearc->points, tmppoints + curseg, thearc->number);
-	    curseg = pathsegs;
-	    break;
       }
    } 
    strokepath(tmppoints, pathsegs, thepath->style, thepath->width);
@@ -2075,7 +2253,6 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
 			TOLABEL(areagen)->pin != INFO && areawin->pinpointon)
 		UDrawXDown(TOLABEL(areagen));
 	     break;
-
        }
      }
 
