@@ -12,8 +12,10 @@
 #include <string.h>
 #include <math.h>
 
+#ifndef _MSC_VER
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
+#endif
 
 #ifdef OPENGL
 #include <GL/gl.h>
@@ -213,7 +215,7 @@ void transform_graphic(graphicptr gp)
 void UDrawGraphic(graphicptr gp)
 {
     XPoint ppt;
-    int width, height;
+    /* int width, height; (jdk) */
 
     if (gp->valid == FALSE) transform_graphic(gp);
     if (gp->valid == FALSE) return;			/* Error condition */
@@ -285,7 +287,7 @@ graphicptr new_graphic(objinstptr destinst, char *filename, int px, int py)
     objinstptr locdestinst;
     Imagedata *iptr;
     FILE *fg;
-    int nf, nr, width, height, imax, x, y, i;
+    int nr, width, height, imax, x, y, i; /* nf, (jdk) */
     char id[5], c, buf[128];
     union {
        u_char b[4];
