@@ -1655,7 +1655,11 @@ void catalog_op(int op, int x, int y)
 	          }
 	          else {
                      eventmode = MOVE_MODE;
-	             areawin->editcycle = 1;
+		     /* This is a hack, but avoids having to define a	*/
+		     /* separate event type for a move following a	*/
+		     /* library selection, just so we can handle	*/
+		     /* "cancel" differently.				*/
+	             areawin->editpart = -1;
 	          }
 #ifdef TCL_WRAPPER
 		  /* fprintf(stderr, "Creating event handler for xctk_drag: "); */
