@@ -1269,7 +1269,7 @@ void stringparam(xcWidget w, caddr_t clientdata, caddr_t calldata)
          unselect_all();
 	 setparammarks(NULL);
       }
-      else if (checkselect(LABEL)) parameterize(P_SUBSTRING, _STR2);
+      else if (checkselect(LABEL)) parameterize(P_SUBSTRING, _STR2, -1);
 }
 
 /*--------------------------------------------------------------*/
@@ -1285,7 +1285,7 @@ void startparam(xcWidget w, pointertype value, caddr_t calldata)
       stringparam(w, NULL, NULL);
    }
    else if ((eventmode != NORMAL_MODE) || (areawin->selects > 0))
-	 parameterize((int)value, (char *)calldata);
+	 parameterize((int)value, (char *)calldata, -1);
 }
 
 /*---------------------------------------------------------------*/
