@@ -725,6 +725,7 @@ typedef struct {
    u_short	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
+   short	cycle;		/* Edit position, or -1	*/
    XPoint	position;
    short	rotation;
    float	scale;
@@ -741,6 +742,7 @@ typedef struct {
    u_short	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
+   short	cycle;		/* Edit position, or -1	*/
    u_short	style;
    float	width;
    short	number;
@@ -755,6 +757,7 @@ typedef struct {
    u_short	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
+   short	cycle;		/* Edit position, or -1	*/
    u_short	style;
    float	width;
    XPoint	ctrl[4];
@@ -770,6 +773,7 @@ typedef struct {
    u_short	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
+   short	cycle;		/* Edit position, or -1	*/
    u_short	style;
    float	width;
    short	radius; 	/* x-axis radius */
@@ -1221,7 +1225,7 @@ enum {
    XCF_Text_Split /* 24 */,	XCF_Text_Home /* 25 */,
    XCF_Text_End /* 26 */,	XCF_Linebreak /* 27 */,
    XCF_Parameter /* 28 */,	XCF_Edit_Param /* 29 */,
-   XCF_Edit_Break /* 30 */,	XCF_Edit_Delete /* 31 */,
+   XCF_ChangeStyle /* 30 */,	XCF_Edit_Delete /* 31 */,
    XCF_Edit_Insert /* 32 */,	XCF_Edit_Append /* 33 */,
    XCF_Edit_Next /* 34 */,	XCF_Attach /* 35 */,
    XCF_Next_Library /* 36 */,	XCF_Library_Directory /* 37 */,
@@ -1261,7 +1265,7 @@ enum {
    XCF_Sim /* 104 */,		XCF_SPICE /* 105 */,
    XCF_PCB /* 106 */,		XCF_SPICEflat /* 107 */,
    XCF_Color /* 108 */,		XCF_Text_Delete_Param /* 109 */,
-   XCF_Scale /* 110 */,		XCF_ChangeStyle /* 111 */,
+   XCF_Scale /* 110 */,
    NUM_FUNCTIONS
 };
 
@@ -1343,7 +1347,7 @@ typedef struct _windowdata {
    char		buschar;	/* Character indicating vector notation */
    Boolean	editinplace;
    Boolean	pinpointon;
-   Boolean	attachto;
+   Boolean	pinattach;	/* keep wires attached to pins when moving objinsts */
 #ifndef TCL_WRAPPER
 #ifdef HAVE_XPM
    Boolean	toolbar_on;
@@ -1354,6 +1358,8 @@ typedef struct _windowdata {
    XPoint	save, origin;
    short	selects;
    short	*selectlist;
+   short	editpart;
+   short	attachto;
    short	lastlibrary;
    objinstptr	topinstance;
    objectptr	editstack;
@@ -1361,8 +1367,6 @@ typedef struct _windowdata {
    pushlistptr	stack;
    pushlistptr	hierstack;
    short	event_mode;
-   short	editcycle;
-   short	editpart, editsubpart;
    char		*lastbackground;
    Cursor	*defaultcursor;
 } XCWindowData;
